@@ -2,7 +2,6 @@
 //
 // All rights reserved. Distributed under LGPL 3.0. For full terms see the file LICENSE.
 
-
 use self::AxesVariant::*;
 use axes2d::*;
 use axes3d::*;
@@ -56,7 +55,12 @@ impl Figure
 	/// Creates a new figure
 	pub fn new() -> Figure
 	{
-		Figure { axes: Vec::new(), terminal: "".to_string(), output_file: "".to_string(), gnuplot: RefCell::new(None) }
+		Figure {
+			axes: Vec::new(),
+			terminal: "".to_string(),
+			output_file: "".to_string(),
+			gnuplot: RefCell::new(None),
+		}
 	}
 
 	/// Sets the terminal for gnuplot to use, as well as the file to output the figure to.
@@ -123,7 +127,9 @@ impl Figure
 			);
 		}
 
-		self.gnuplot.borrow_mut().as_mut().map(|p| { self.echo(p.stdin.as_mut().expect("No stdin!?")); });
+		self.gnuplot.borrow_mut().as_mut().map(|p| {
+			self.echo(p.stdin.as_mut().expect("No stdin!?"));
+		});
 
 		self
 	}
